#!/usr/bin/env python

import sys

import grass.script as grass
import grass.script.setup as gsetup

def main():
    


    # Floating value rasters (German names)
    for i in ['AZ_ART_SUB','WS_BR','WSTIEF_A','SUB_T','SUB_S','SUB_K','SUB_ST','SUB_BL','SUB_SCH','SUB_HN','SUB_TH','SUB_DE','SUB_W','SUB_M','SUBD','F_KR','F_BEW','F_LP_E','F_AV_SUB','F_SVERB_BE','F_PTIEF','F_BR_ENTW','F_PF','F_NTU','F_NTB','F_UVERB','F_GRS','F_VL','H_LAUF_ENT','H_LP','H_SSTR','H_QP','H_USTR','H_GEW_UF','B_SOHLE','B_UFER','B_LAND','GESAMT','rLSTR_01','rLSTR_02','rLSTR_03','rLSTR_04','rLSTR_05','rLSTR_06','rUSTR_01','rUSTR_02','rUSTR_03','rUSTR_04','rUSTR_05','rUSTR_06','rUSTR_07','rSSTR_01','rSSTR_02','rSSTR_03','rSSTR_04','rSSTR_05','rB_SO_01','rB_SO_02','rB_SO_03','rB_SO_04','rB_SO_05','rB_SO_06']:

        
        grass.run_command("v.to.rast",
                    input = "DSV_Treene_gen@SDM_Treene",
                    overwrite=True,
                    output = "rast_"+i,
                    type = "line",
                    use = "attr",
                    column = i)



    # Categorial rasters (German names)
    for i in ['ART_SVERB','BRVAR','WFUEHR','LAUFKR','PTYP','FL_G_AKT','TIEFV','STRD_A','U_VER_L','U_VER_R','S_W_VEG','UFB_L','UFB_R']:

        grass.run_command("v.to.rast",
                    input = "DSV_Treene_gen@SDM_Treene",
                    overwrite=True,
                    output = "crast_"+i,
                    type = "line",
                    use = "attr",
                    column = i,
                    labelcolumn = i)

        grass.run_command("r.null",
                    map = "crast_"+i,
                    setnull = "0",
                    overwrite = True)

    # Treene raster
    grass.run_command("fidimo.river.py",
                    input = "DSV_Treene_gen@SDM_Treene",
                    overwrite = True,
                    output= "Treene_raster")



    #Combine all Rasters - create mask (all rasters with non-NULL)
    mask_list = grass.read_command("g.mlist",
                                pattern = "rast_*|crast_*|Treene_raster").splitlines()
    grass.run_command("r.series",
                    input = mask_list,
                    overwrite = True,
                    flags = "n",
                    output = "Treene_tmp_mask",
                    method = "count")

    grass.mapcalc("$Treene_mask = if($Treene_tmp_mask)",
                    Treene_mask = "Treene_mask",
                    Treene_tmp_mask = "Treene_tmp_mask")
                    
    grass.write_command("r.category",
                    map = "Treene_mask",
                    rules = "-",
                    stdin = '1:1')

    

    
    #clean up
    grass.run_command("g.remove",
                    rast = "Treene_tmp_mask")


    export_list = grass.read_command("g.mlist",
                                pattern = "rast_*|crast_*|Treene_mask").splitlines()
    for i in export_list:
        grass.run_command("r.out.gdal",
                    flags = "c",
                    #nodata = "NA",
                    input = i,
                    output = "/path/to/output/data/Treene/SDM/Predictors/"+i+".tif")  


    return 0

if __name__ == "__main__":
    sys.exit(main())
